<?php

/**
 * @file
 * Drush extension for myDropWizard module.
 */

function mydropwizard_drush_command() {
  return array(
    'mydropwizard-list-projects' => array(
      'description' => 'Outputs the list of enabled projects on this site.',
      'options' => array(
        'branch-only' => 'Only output the major branch version - not the full version string',
        'header-row' => 'Add a header row for use with --format=csv',
        'no-rebuild' => 'Skip rebuilding system data before gathering vitals',
      ),
      'outputformat' => array(
        'default' => 'table',
        'pipe-format' => 'csv',
        'field-labels' => array('project' => 'Project', 'version' => 'Version'),
        'fields-default' => array('project', 'version'),
        'output-data-type' => 'format-table',
      ),
    ),
  );
}

function _drush_mydropwizard_return_table($data) {
  if (DRUSH_MAJOR_VERSION >= 6) {
    return $data;
  }

  $command = drush_get_command();
  $rows = array();

  // Build the header.
  $row = array();
  foreach ($command['outputformat']['fields-default'] as $key) {
    $row[] = dt($command['outputformat']['field-labels'][$key]);
  }
  $rows[] = $row;

  // Build the subsequent rows.
  foreach ($data as $item) {
    $row = array();
    foreach ($command['outputformat']['fields-default'] as $key) {
      $row[] = $item[$key];
    }
    $rows[] = $row;
  }

  drush_print_table($rows, TRUE);
}

function drush_mydropwizard_list_projects() {
  require_once dirname(__FILE__) . '/mydropwizard.data.inc';

  $rebuild = !drush_get_option('no-rebuild');

  $system_data = _mydropwizard_get_raw_system_data($rebuild);
  $project_data = _mydropwizard_gather_vitals_project_data($system_data);

  $data = array();
  if (drush_get_option('header-row')) {
    $data[] = array(
      'project' => 'Project',
      'version' => 'Version',
    );
  }

  foreach ($project_data as $project) {
    $name = $project['name'];
    $version = $project['value'];

    // Switch to only major branch version.
    if (drush_get_option('branch-only')) {
      // Extract the major version part.
      if (preg_match('/^(\d+)/', $version, $matches)) {
        $version = $matches[1];
      }
      else {
        $version = '0';
      }
    }

    $data[] = array(
      'project' => $name,
      'version' => $version,
    );
  }

  return _drush_mydropwizard_return_table($data);
}

